<?php

$locale["  %d%% (%d/%d)"] =
   "  %d%% (%d/%d)";
$locale[" (syntax error for latex) "] =
   " (erreur de syntaxe pour latex) ";
$locale[" (to pages linked from \"%s\")"] =
   " (aux pages lies  \"%s\")";
$locale[" - %d / %d - "] =
   " - %d / %d - ";
$locale[" ... around %s"] =
   "... autour de %s";
$locale[" ... first %d bytes"] =
   "... premiers %d octets";
$locale[" ... first %d lines"] =
   "... %d premires lignes";
$locale[" Additionally, try to keep the latest contributions of all authors in the last %d days (even if there are more than %d of them,) but in no case keep more than %d unique author revisions."] =
   "De plus, essayez de conserver les dernires contributions de tous les auteurs depuis les %d derniers jours (mme s'il y en a plus que %d), mais ne conservez en aucun cas plus que %d rvisions par auteur.";
$locale[" Keep the latest contributions of the last %d authors up to %d days."] =
   "Garder les dernires contributions des derniers %d auteurs jusqu' %d jours.";
$locale[" Keep up to %d minor edits, but keep them no longer than %d days."] =
   "Garder jusqu' %d dition mineures, mais pas plus que %d jours.";
$locale[" Sorry, cannot merge."] =
   " Dsol, impossible de fusionner.";
$locale[" This is for small text"] =
   "C'est pour des petits textes";
$locale[" replace "] =
   " remplace ";
$locale[" skipped"] =
   " ignor";
$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%d UserPreferences fields successfully updated."] =
   "%d PrfrencesUtilisateurs mises  jour avec succs.";
$locale["%d best incoming links: "] =
   "%d meilleurs liens entrants : ";
$locale["%d best outgoing links: "] =
   "%d meilleurs liens sortants : ";
$locale["%d homepages"] =
   "%d pages d'accueil";
$locale["%d minutes"] =
   "%d minutes";
$locale["%d most popular nearby: "] =
   "%d pages les plus visites aux alentours : ";
$locale["%d not-empty pages"] =
   "%d pages non vides";
$locale["%d online users"] =
   "%d visiteurs en ligne";
$locale["%d page(s) with more than %d hits (>%d%%)."] =
   "%d pages ayant eu plus de %d visiteurs (>%d%%).";
$locale["%d pages"] =
   "%d pages";
$locale["%d pages have been permanently removed."] =
   "%d pages ont t dfinitivement supprimes.";
$locale["%d pages with less than %d hits (<%d%%)."] =
   "%d pages ayant eu moins de %d visiteurs (<%d%%).";
$locale["%s %s %s is disallowed on this wiki for %s user '%s' (level: %s)."] =
   "%s %s %s est interdite sur ce wiki pour %s l'utilisateur '%s' (niveau : %s).";
$locale["%s Kb (%s bytes)"] =
   "%s Ko (%s octets)";
$locale["%s already exists"] =
   "%s existe dj";
$locale["%s at %s"] =
   "%s  %s";
$locale["%s b"] =
   "%s b";
$locale["%s by %s"] =
   "%s par %s";
$locale["%s bytes"] =
   "%s octets";
$locale["%s bytes written"] =
   "%s octets enregistrs";
$locale["%s days"] =
   "%s jours";
$locale["%s does not appear to be a WikiPlugin."] =
   "%s ne semble pas tre un plugin.";
$locale["%s does not exist"] =
   "%s n'existe pas";
$locale["%s does not know about the language '%s', using 'en' instead."] =
   "%s ne connait pas le langage '%s', utilisation de 'en' a la place.";
$locale["%s has no subpages defined."] =
   "La page %s n'a aucune sous-page dfinie.";
$locale["%s is disallowed on this wiki."] =
   "L'action %s est interdite sur ce wiki.";
$locale["%s is empty"] =
   "%s est vide.";
$locale["%s is empty."] =
   "%s est vide.";
$locale["%s is missing"] =
   "%s est manquant";
$locale["%s is not locked!"] =
   "%s n'est pas verrouill!";
$locale["%s is not writable"] =
   "%s n'est pas accessible en criture";
$locale["%s is not writable."] =
   "%s n'est pas accessible en criture.";
$locale["%s is only allowed in locked pages."] =
   "%s n'est autoris que dans les pages verrouilles.";
$locale["%s k"] =
   "%s k";
$locale["%s not found"] =
   "%s non trouv";
$locale["%s of this page"] =
   "%s de cette page";
$locale["%s on %s:"] =
   "%s on %s :";
$locale["%s or %s parameter missing"] =
   "%s ou %s paramtre manquant";
$locale["%s pages changed."] =
   "%s pages modifies.";
$locale["%s pages have been changed."] =
   "Les pages %s ont t changes.";
$locale["%s pages have been permanently changed."] =
   "%s pages ont t dfinitivement modifies.";
$locale["%s pages have been permanently renamed."] =
   "%s pages ont t dfinitivement renommes.";
$locale["%s pages link to %s:"] =
   "%s pages pointent vers %s :";
$locale["%s pages would link to %s:"] =
   "%s pages pointaient vers %s :";
$locale["%s parameter missing"] =
   "%s paramtre manquant";
$locale["%s prediction for you is %.1f stars"] =
   "la prdiction %s pour vous est de %.1f toiles.";
$locale["%s prediction for you is %s stars"] =
   "La prdiction %s pour vous est de %s toiles.";
$locale["%s words"] =
   "%s mots";
$locale["%s(%d): no such revision"] =
   "%s(%d) : rvision inexistante";
$locale["%s: %s"] =
   "%s : %s";
$locale["%s: Bad action"] =
   "%s : Mauvaise action";
$locale["%s: Can't open dba database"] =
   "%s : impossible d'ouvrir la base de donnes dba";
$locale["%s: Date of new revision is %s"] =
   "%s : la date de la nouvelle rvision est %s";
$locale["%s: argument index out of range"] =
   "%s : index d'argument hors intervalle";
$locale["%s: error while handling error:"] =
   "%s : erreur pendant la gestion de l'erreur :";
$locale["%s: file not found"] =
   "%s : fichier non trouv";
$locale["%s: no such class"] =
   "<%s : pas de section de ce type>";
$locale["%s: not a subclass of WikiPlugin."] =
   "%s n'est pas une sous classe de WikiPlugin.";
$locale["%s: not defined"] =
   "%s : non dfini";
$locale["'%s': Bad page name"] =
   "%s : Nom de page invalide";
$locale["'%s': Bad page name: %s"] =
   "'%s': Nom de page invalide : : %s";
$locale["'%s': corrupt file"] =
   "'%s' : ce fichier est abm";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] =
   "(Copiez vos modifications dans le presse-papier. Vous pouvez essayer d'diter une page diffrente ou sauver votre texte dans un diteur).";
$locale["(Currently not working)"] =
   "(Non recommand !)";
$locale["(Pages which have been deleted at least %s days are already checked.)"] =
   "(Les pages qui ont t supprimes il y a au plus %s jours sont dj vrifies.)";
$locale["(Redirected from %s)"] =
   "(Redirig de %s)";
$locale["(User: %s)"] =
   "(Utilisateur : %s)";
$locale["(Your preferences are stored as hidden data within this page)."] =
   "Vos prfrences sont enregistres en mode invisible sur cette page.";
$locale["(diff)"] =
   "(diff)";
$locale["(disable individual page permissions, enable inheritance)?"] =
   "(dsactive les permissions individuelles par page, activer l'hritage) ?";
$locale["(hist)"] =
   "(hist)";
$locale["(max. recursion level: %d)"] =
   "(niveau maximum de rcursivit: %d)";
$locale["(ugo : rwx)"] =
   "(ugo : rwx)";
$locale[", Memory: %s"] =
   ", RAM: %s";
$locale["- saved to database as version %d"] =
   "- sauve dans la base de donnes sous la version %d";
$locale["- version %d saved to database as version %d"] =
   "- version %d sauve dans la base de donnes sous la version %d";
$locale["-???"] =
   "-???";
$locale["... (first %s words)"] =
   "... (%s premiers mots)";
$locale["... copied to %s"] =
   "... copi  %s";
$locale["... not copied to %s"] =
   "... non copi  %s";
$locale["... not found"] =
   "... non trouv";
$locale["1 day"] =
   "1 jour";
$locale["1 word"] =
   "1 mot";
$locale["<%s: no such section>"] =
   "<%s : pas de section de ce type>";
$locale["<<"] =
   "<<";
$locale["<empty>"] =
   "<vide>";
$locale["<no matches>"] =
   "<aucun rsultat>";
$locale["<none>"] =
   "<aucune>";
$locale["<not displayed>"] =
   "<non affich>";
$locale["<system language>"] =
   "< langage du systme >";
$locale["<system theme>"] =
   "<thme systme>";
$locale["<unknown>"] =
   "<inconnue>";
$locale[">>"] =
   ">>";
$locale[">>|"] =
   ">>|";
$locale["A plugin to provide for raw HTML within wiki pages."] =
   "Un Plugin pour intgrer du code HTML dans les WikiPages.";
$locale["A required argument '%s' is missing."] =
   "Un argument requis '%s' est manquant.";
$locale["ACCESS DENIED: You must log in to upload files."] =
   "ACCES REFUSE: Vous devez tre connect pour uploader.";
$locale["ACL"] =
   "ACL";
$locale["ACL changed for page '%s'."] =
   "ACL modifi pour la page %s.";
$locale["ACL not changed for page '%s'."] =
   "ACL inchang pour la page %s.";
$locale["ADDING"] =
   "AJOUT";
$locale["ADMIN"] =
   "ADMIN";
$locale["ANON"] =
   "ANONYME";
$locale["About"] =
   " propos de";
$locale["Access"] =
   "Accs";
$locale["Access denied to change page '%s'."] =
   "Accs refus pour changer la page '%s'.";
$locale["Access for you is forbidden to %s."] =
   "L'accs  %s vous est interdit.";
$locale["Action page"] =
   "Page d'action";
$locale["Add %s hours to the server's local time when reporting times."] =
   "Ajouter %s heures  l'heure locale du serveur pour afficher les horodatages.";
$locale["Add %s:"] =
   "Ajouter %s :";
$locale["Add Comment"] =
   "Ajouter un commentaire";
$locale["Add Google links to unknown pages behind the '?', and the create action behind the pagename instead. See %s."] =
   "Ajouter un liens vers Google pour les pages inconnues derrire le '?', et l'action de cration. voir %s.";
$locale["Add Message"] =
   "Ajouter un message";
$locale["Add a Comment"] =
   "Ajouter un commentaire";
$locale["Add or change a page-level metadata 'key=>value' pair. Note that you can remove a key by leaving the value-box empty."] =
   "Ajouter ou changer le niveau de page 'key=>value'. Notez que vous pouvez supprimer une cl en lui attribuant une valeur nulle.";
$locale["Add this ACL"] =
   "Ajouer cette ACL";
$locale["AddCategory"] =
   "AjoutezCatgorie";
$locale["AddComment"] =
   "AjouterDesCommentaires";
$locale["AddCommentPlugin"] =
   "AjoutDesCommentaires";
$locale["AddPageLink"] =
   "AjouterDesPagesLien";
$locale["AddPlugin"] =
   "AjoutezPlugin";
$locale["AddingPages"] =
   "AjouterDesPages";
$locale["Adjust"] =
   "Ajuster";
$locale["Admin"] =
   "Administrateur";
$locale["Admin is also online."] =
   "L'administrateur est aussi en ligne.";
$locale["Administrators"] =
   "Administrateures";
$locale["All %s are listed below."] =
   "Toutes les %s sont numres ci-dessous.";
$locale["All pages in this wiki (%d total):"] =
   "Pages dans ce wiki (%d au total) :";
$locale["All pages with all links in this wiki (%d total):"] =
   "Tout pages avec tous les liens dans ce wiki (%d au total) :";
$locale["AllPages"] =
   "ToutesLesPages";
$locale["AllPagesOwnedByMe"] =
   "ToutesMesPages";
$locale["AllUsers"] =
   "TousLesUtilisateurs";
$locale["Allow / Deny"] =
   "Autoriser / Refuser";
$locale["Allowed protocols"] =
   "Protocoles autoriss";
$locale["Allows selection of multiple pages which get passed to other WikiAdmin plugins."] =
   "Permet de choisir plusieurs pages qui seront passes vers d'autre plugins WikiAdmin.";
$locale["Also pages which have been deleted at least %s days."] =
   "Mme les pages qui ont t supprimes il y a au plus %s days.";
$locale["An unnamed PhpWiki"] =
   "Un PhpWiki sans titre";
$locale["Anonymous Users"] =
   "Utilisateur anonyme";
$locale["Appearance"] =
   "Apparence";
$locale["Append text to any page in this wiki."] =
   "Apposez le texte  n'importe quelle page de ce wiki.";
$locale["AppendText"] =
   "ApposezLeTexte";
$locale["Application name"] =
   "Nom de l'application";
$locale["Application size: %d Kb"] =
   "Taille de l'application : %d Kb";
$locale["Are you sure you want to permanently change access to the selected files?"] =
   "tes-vous sr de vouloir dfinitivement modifier l'accs aux fichiers slectionns ?";
$locale["Are you sure you want to permanently change the selected files?"] =
   "Supprimer la page maintenant";
$locale["Are you sure you want to permanently chown the selected files?"] =
   "tes-vous sr de vouloir changer dfinitivement le propritaire des pages slectionnes ?";
$locale["Are you sure you want to permanently remove the selected files?"] =
   "tes-vous certain de vouloir supprimer dfinitivement les fichiers slectionns ?";
$locale["Are you sure you want to permanently rename the selected files?"] =
   "tes-vous certain de renommer dfinitivement les pages slectionnes ?";
$locale["Are you sure you want to permanently search & replace text in the selected files?"] =
   "Etes-vous sur de vouloir rechercher et remplacer dans les fichiers slectionnes ?";
$locale["Argument '%s' not declared by plugin."] =
   "argument '%s' non dclar par le plugin.";
$locale["Arguments"] =
   "Arguments";
$locale["Attempting to use the directory '%s' instead."] =
   "Tentative d'utilisation du rpertoire '%s'  la place.";
$locale["Auth Level"] =
   "Niveau de l'authentification";
$locale["Auth Method"] =
   "Mthode d'authentification";
$locale["AuthInfo"] =
   "InfosAuth";
$locale["Authenticated Users"] =
   "Utilisateurs connects";
$locale["Authenticated as %s"] =
   "Vous tes connect en tant que %s";
$locale["Authenticated users on this wiki (%d total):"] =
   "Utilisateurs connects  ce wiki (%d au total) :";
$locale["Author"] =
   "Auteur";
$locale["Author will be logged as %s."] =
   "L'auteur sera enregistr sous le nom %s.";
$locale["AuthorHistory"] =
   "HistoriqueAuteur";
$locale["AuthorHistoryPlugin"] =
   "PluginHistoriqueAuteur";
$locale["Automatically link headers at the top"] =
   "Crer une table des matires des titres et sous-titres en haut";
$locale["Available plugins"] =
   "Plugins disponibles";
$locale["Avg. Rating"] =
   "Cote moyenne";
$locale["BAD URL -- remove all of <, >, \""] =
   "MAUVAIS URL -- retirez tous les <, >, \"";
$locale["BAD phpwiki: URL"] =
   "MAUVAIS phpwiki: URL";
$locale["BOGO"] =
   "BOGO";
$locale["Back to the previous page."] =
   "Retournez  la page prcdente.";
$locale["BackLinks"] =
   "RtroLiens";
$locale["BackLinks for %s"] =
   "RtroLiens pour %s";
$locale["Bad Version"] =
   "Mauvaise Version";
$locale["Bad file type: %s"] =
   "Mauvais type de fichier : %s";
$locale["Bad url in src: remove all of <, >, \""] =
   "Mauvaise url dans la source : retirez tous les <, >, \"";
$locale["Blog page"] =
   "Page de Blog";
$locale["Blogs"] =
   "Blogs";
$locale["Bogo Users"] =
   "Utilisateurs Bogo";
$locale["Bold text"] =
   "Texte en gras";
$locale["Browsing pages"] =
   "Navigation en cours";
$locale["CANCEL"] =
   "ANNULE";
$locale["CREATED"] =
   "CR";
$locale["Cache statistics"] =
   "Statistiques de cache";
$locale["Calendar"] =
   "Calendrier";
$locale["CalendarList"] =
   "ListeDuCalendrier";
$locale["CalendarListPlugin"] =
   "PluginListeDuCalendrier";
$locale["CalendarPlugin"] =
   "PluginCalendrier";
$locale["Can't inflate data: zlib support not enabled in this PHP"] =
   "Impossible de dcompresser les donnes : le support de zlib n'a pas t valid dans ce PHP";
$locale["Can't mix '%s' with '%s' type format strings"] =
   "Impossible de mlanger les chanes de type '%s' et '%s'";
$locale["Can't open the upload logfile."] =
   "Erreur: Impossible d'ouvrir le journal des fichiers dposs.";
$locale["Can't open zip file '%s' for reading"] =
   "Impossible d'ouvrir le fichier zip '%s' en lecture";
$locale["Cancel"] =
   "Annuler";
$locale["Cancel rating"] =
   "Annuler la notation";
$locale["Cannot create directory '%s'"] =
   "Impossible de crer le rpertoire '%s'";
$locale["Cannot open AUTH_GROUP_FILE %s"] =
   "Impossible d'ouvrir AUTH_GROUP_FILE %s";
$locale["Case insensitive?"] =
   "Sensible  la casse ?";
$locale["CategoryCategory"] =
   "CatgorieCatgorie";
$locale["CategoryGroup"] =
   "CatgorieGroupes";
$locale["CategoryHomePages"] =
   "CatgoriePagesAccueil";
$locale["CategoryHomepage"] =
   "CatgoriePagesAccueil";
$locale["CategoryPage"] =
   "CatgoriePages";
$locale["Change Password"] =
   "Changer le Mot de passe";
$locale["Change Verification Status"] =
   "Changer la vrification du statut";
$locale["Change country"] =
   "Changer le pays";
$locale["Change page attributes"] =
   "Changer les attributs de cette page";
$locale["Change pagename in all linked pages also?"] =
   "Changer les noms de pages dans toutes les pages lies ?";
$locale["Check any two boxes then %s."] =
   "Cochez une bote puis %s.";
$locale["Check any two boxes to compare revisions."] =
   "Cochez une des botes pour comparer les rvisions.";
$locale["Check to add this ACL"] =
   "Vrifier pour ajouter cette ACL";
$locale["Chmod"] =
   "Chmod";
$locale["Chmod to permission:"] =
   "Changer le mode de permission  :";
$locale["Chown"] =
   "Chown";
$locale["Chown page '%s' to '%s'."] =
   "Changement de propritaire %s  %s.";
$locale["Chown selected pages"] =
   "Changer le propritaire des pages slectionnes";
$locale["Chown selected pages."] =
   "Changer le propritaire des pages selectionnes.";
$locale["Click a button to get an example text"] =
   "Cliquer sur un bouton pour obtenir une exemple de texte";
$locale["Click to authenticate as %s"] =
   "Cliquez pour vous conneter en tant que %s";
$locale["Click to de-/select all pages"] =
   "Cliquez pour (de)slectionner toutes les pages";
$locale["Click to display"] =
   "Cliquez pour afficher";
$locale["Click to display all comments"] =
   "Cliquez pour afficher tout commente";
$locale["Click to reverse sort order"] =
   "Cliquer pour inverser l'ordre de tri";
$locale["Click to sort by %s"] =
   "Cliquer pour trier par %s";
$locale["Close"] =
   "Fermer";
$locale["Columns: %s."] =
   "Colonnes : %s.";
$locale["Comment"] =
   "Commentaire";
$locale["Comment modified on %s by %s"] =
   "Commentaire modifi le %s par %s";
$locale["CommentPlugin"] =
   "PluginCommenter";
$locale["Comments"] =
   "Commentaires";
$locale["Comments on %s by %s."] =
   "Commentaire le %s par %s.";
$locale["Complete."] =
   "Termin.";
$locale["Conflicting Edits!"] =
   "Conflit d'ditions !";
$locale["Content"] =
   "Contenu";
$locale["Contents"] =
   "Contenu";
$locale["ContributedTranslations"] =
   "TraductionsContribues";
$locale["Control characters not allowed"] =
   "Caractres de contrle, non autoriss";
$locale["Convert"] =
   "Converti";
$locale["Convert Tex mathematicals expressions to cached png files."] =
   "Convertit des expressions mathmatiques au format TeX en des fichiers png mis en cache.";
$locale["Convert text into a png image using GD."] =
   "Converti le texte en une image png utilisant GD.";
$locale["Converted successfully %d pages"] =
   "%d pages converties avec succs";
$locale["Converts TeX to an image. May be used to embed formulas in PhpWiki."] =
   "Pour convertir des formules TeX en image.";
$locale["Copyrights"] =
   "Copyrights";
$locale["Couldn't chmod page '%s' to '%s'."] =
   "Impossible de changer le mode '%s'  '%s'.";
$locale["Couldn't chown page '%s' to '%s'."] =
   "Impossible de changer le propritaire '%s'  '%s'.";
$locale["Couldn't connect to %s"] =
   "Impossible d'tablir une connexion  la base de donnes : %s";
$locale["Couldn't rename page '%s' to '%s'."] =
   "Impossible de renommer la page '%s' en '%s'.";
$locale["Couldn't start commandline '%s'"] =
   "Impossible de lancer la ligne de commande '%s'";
$locale["Count"] =
   "Compte";
$locale["Create a Wiki page by the provided name."] =
   "Crer une PageWiki avec le nom demand.";
$locale["Create a Wiki page."] =
   "Crer cette page.";
$locale["Create a new (sub)page"] =
   "Crer une nouvelle (sous)page";
$locale["Create: %s"] =
   "Enregistre : %s";
$locale["CreatePage"] =
   "CrerUnePage";
$locale["CreateToc"] =
   "CrerUneTdm";
$locale["CreateTocPlugin"] =
   "PluginCrerUneTdm";
$locale["Created by CreatePage"] =
   "Cre par CrerUnePage";
$locale["Created directory '%s' for the page dump..."] =
   "Rpertoire '%s' cr pour la sauvegarde...";
$locale["Creating pages"] =
   "Cration des pages";
$locale["Creator"] =
   "Crateur";
$locale["Current Language"] =
   "Langage courant";
$locale["Current Theme"] =
   "Thme courant";
$locale["Current language: '%s'"] =
   "Langage actuel : %s";
$locale["Current theme: '%s'"] =
   "Thme actuel : '%s'";
$locale["Currently not recommended!"] =
   "Non recommand !";
$locale["DB admin password:"] =
   "DB admin mot de passe :";
$locale["DB admin user:"] =
   "DB admin nom de user :";
$locale["Database"] =
   "Base de donnes";
$locale["Date Format"] =
   "Format de Date";
$locale["DeadEndPages"] =
   "PagesSansLien";
$locale["DebugGroupInfo"] =
   "InfosDeDboguageGroupe";
$locale["DebugInfo"] =
   "InfosDeDboguage";
$locale["Default InterWiki map file not loaded."] =
   "Carte InterWiki par dfaut non charge.";
$locale["Default language: '%s'"] =
   "Langage par dfaut : %s";
$locale["Default preferences will be used."] =
   "Les prfrences par dfaut seront utilises.";
$locale["Default theme: '%s'"] =
   "Thme par dfaut : '%s'";
$locale["Define a translation for a specified text"] =
   "Traduire du texte";
$locale["Define the translation for %s in %s"] =
   "Dfinir la traduction pour %s en %s";
$locale["Del/+"] =
   "Effacer/+";
$locale["Delete this ACL"] =
   "Effacer cette ACL";
$locale["Deleted"] =
   "Supprim";
$locale["Deleted %s pages with invalid names:"] =
   "%s pages ont t supprimes  cause de leur nom invalide:";
$locale["Describe %s here."] =
   "Dcrire %s ici.";
$locale["Description"] =
   "Description";
$locale["Description: Provides a list of plugins on this wiki."] =
   "Affiche la liste des Plugins de ce wiki.";
$locale["Dialog"] =
   "Dialogue";
$locale["Didn't removed page '%s'. Access denied."] =
   "Page '%s' non supprime. Accs refus.";
$locale["Diff"] =
   "Diff";
$locale["Diff previous Author"] =
   "Auteur Prcdent";
$locale["Diff previous Revision"] =
   "Diffrence avec la rvision prcdente";
$locale["Diff: %s"] =
   "Diff : %s";
$locale["Differences between %s and %s of %s."] =
   "Diffrences entre %s et %s de %s.";
$locale["Diffing pages"] =
   "Comparaison des pages";
$locale["Discussion"] =
   "Entretien";
$locale["Display arbitrary SQL result tables"] =
   "Affiche le rsultat de requtes SQL simples";
$locale["Display differences between revisions"] =
   "Affiche les diffrences entre rvisions";
$locale["Display general and user specific auth information."] =
   "Afficher les informations gnrales de l'utilisateur.";
$locale["Displays a list of randomly chosen pages or redirects to a random page."] =
   "Affiche une liste de pages prises au hasard sur ce wiki.";
$locale["Displays a set of photos listed in a text file with optional descriptions"] =
   "Affiche un groupe de photos listes dans un fichier texte avec des descriptions facultatives.";
$locale["Displays a url in a seperate frame inside our body. Only one frame allowed."] =
   "Affiche une url dans une cadre interne  la page. Un seul cadre autoris.";
$locale["Do you really want to delete all your UserPreferences?"] =
   "Voulez-vous rellement effacer toutes vos PrfrencesUtilisateurs ?";
$locale["Don't cache this page."] =
   "Ne pas mettre en cache cette page.";
$locale["Double redirect not allowed."] =
   "La double redirection interdit.";
$locale["Download for CVS"] =
   "Tlcharger pour CVS";
$locale["Download for backup"] =
   "Tlcharger pour sauvegarder";
$locale["Download the page contents"] =
   "Tlcharger le contenu de la page";
$locale["Downloading html zip dumps"] =
   "Tlchargement des sauvegardes html compresses";
$locale["Downloading zip dumps"] =
   "Tlchargement des sauvegardes compresses";
$locale["Dump Pages"] =
   "Rcuprer les pages";
$locale["Dump Pages as XHTML"] =
   "Sauvegarde des pages au format XHTML";
$locale["Dump pages as XHTML"] =
   "Sauvegarde des pages au format xhtml";
$locale["Dump to directory"] =
   "Rcupration dans le rpertoire";
$locale["Dumping Pages"] =
   "Rcupration des pages";
$locale["Dumping html pages"] =
   "Rcupration des pages HTML";
$locale["Dumping serial pages"] =
   "Rcupration des pages srialises";
$locale["E-Mail"] =
   "E-mail";
$locale["E-Mail address '%s' is not properly formatted"] =
   "L'adresse '%s' ne semble pas tre une adresse correcte.";
$locale["E-Mail address '%s' is properly formatted"] =
   "L'adresse E-Mail '%s' semble tre une adresse correcte.";
$locale["E-mail"] =
   "E-mail";
$locale["ERROR uploading '%s': "] =
   "ERREUR en dposant '%s' : ";
$locale["Easy navigation buttons for %s"] =
   "Boutons de navigation rapide pour %s";
$locale["Edit"] =
   "diter";
$locale["Edit %s"] =
   "diter %s";
$locale["Edit Area Size"] =
   "ditez la taille de la zone";
$locale["Edit Old Revision"] =
   "diter l'ancienne rvision";
$locale["Edit aborted."] =
   "dition annule.";
$locale["Edit metadata for %s"] =
   "diter les mtadonnes pour %s";
$locale["Edit old revision"] =
   "diter l'ancienne rvision";
$locale["Edit this page"] =
   "diter cette page";
$locale["Edit this page and all subpages"] =
   "diter cette page et toutes ses sous pages";
$locale["Edit: %s"] =
   "diter : %s";
$locale["EditMetaData"] =
   "EditerLesMetaDonnes";
$locale["EditMetaDataPlugin"] =
   "PluginditerMetaData";
$locale["EditText"] =
   "diterLeContenu";
$locale["Edited by: %s"] =
   "dit par : %s";
$locale["Editing pages"] =
   "ditions des pages";
$locale["Either %s is missing or DATABASE_TYPE != '%s'"] =
   "%s est manquant ou DATABASE_TYPE != '%s'";
$locale["Elapsed time: %s s"] =
   "Temps coul : %s s";
$locale["Email Verification"] =
   "Verrification de l'email";
$locale["Email not yet verified."] =
   "Email pas encore vrifi.";
$locale["Email verified."] =
   "Email vrifi.";
$locale["Embed hidden comments in WikiPages."] =
   "Cacher des commentaires dans une PageWiki.";
$locale["Embedded image"] =
   "Image embarque";
$locale["Empty Preferences or format of UserPreferences cookie not recognised."] =
   "PrfrencesUtilisateurs vides, le cookie peut etre mal reconnu.";
$locale["Empty link to: %s"] =
   "Aucune correspondance de lien pour %s.";
$locale["Empty pagename!"] =
   "La page n'a aucun titre !";
$locale["Enable configurable polls"] =
   "Permettre de faire des sondages configurables";
$locale["Enter pages seperated by space or comma. Wildcards (fileglobbing) allowed."] =
   "Entrer les pages spares par des virgules.";
$locale["Enter your UserId to sign in"] =
   "Entrez votre identifiant utilisateur pour vous connecter";
$locale["Error: Empty search string."] =
   "Erreur: chane vide invalide.";
$locale["Error: The user HomePage must be a valid WikiWord. Sorry, UserPreferences cannot be saved."] =
   "La page d'Accueil d'un utilisateur doit tre un NomWiki valide. PrfrencesUtilisateurs ne peuvent pas tre sauves.";
$locale["Every"] =
   "Toutes";
$locale["Example.jpg"] =
   "Example.jpg";
$locale["Existing page-level metadata for %s:"] =
   "Mtadonnes existantes pour niveau de pages pour %s :";
$locale["Expiry parameters"] =
   "Expiration des paramtres";
$locale["External Links"] =
   "Liens exterieurs";
$locale["External link (remember http:// prefix)"] =
   "Lien externe (http:// prefix)";
$locale["ExternalSearch"] =
   "RechercheExterne";
$locale["ExternalSearchPlugin"] =
   "PluginRechercheExterne";
$locale["FAILED"] =
   "CHOU";
$locale["FIXED"] =
   "CORRIG";
$locale["FORBIDDEN"] =
   "INTERDIT";
$locale["Fatal PhpWiki Error"] =
   "Erreur Fatale de PhpWiki";
$locale["File successfully uploaded."] =
   "Fichier transfr avec succs.";
$locale["FileInfo"] =
   "FichierInfo";
$locale["Files with extension %s are not allowed."] =
   "%s: extension interdit.";
$locale["FindPage"] =
   "ChercherUnePage";
$locale["First"] =
   "Premire";
$locale["FoafViewerPlugin"] =
   "PluginFoafViewer";
$locale["FrameInclude"] =
   "InclureUnCadre";
$locale["FrameIncludePlugin"] =
   "PluginInclureUnCadre";
$locale["From english to %s: "] =
   "De l'Anglais au %s: ";
$locale["Full Search"] =
   "Recherche en Texte Intgral";
$locale["Full text search results for '%s'"] =
   "Rsultats de la recherche en texte intgral de ' %s '";
$locale["FullDump"] =
   "SauvegardeTotale";
$locale["FullRecentChanges"] =
   "DerniresModifs";
$locale["FullTextSearch"] =
   "RechercheEnTexteIntgral";
$locale["FuzzyPages"] =
   "PagesFloues";
$locale["General Auth Settings"] =
   "Prfrences gnrales d'auteur";
$locale["Get an email notification at changes of the following pages:"] =
   "Recevoir un e-mail de notification lors des changements de cette page :";
$locale["Get debugging information for %s."] =
   "Obtenir des infos de dboguage pour %s.";
$locale["Get preferences information for current user %s."] =
   "Obtenir des infos de prfrences pour l'utilisateur %s.";
$locale["Given password ignored."] =
   "Mot de passe ignor.";
$locale["Go"] =
   "OK";
$locale["Go to or create page."] =
   "Aller  ou crer page.";
$locale["Go?"] =
   "Allons-y ?";
$locale["GoTo"] =
   "AllerVers";
$locale["GoodStyle"] =
   "StyleCorrect";
$locale["Google:%s"] =
   "Google: %s";
$locale["GooglePlugin"] =
   "PluginGoogle";
$locale["Grant"] =
   "Accorder";
$locale["Group %s does not exist"] =
   "Le groupe %s n'existe pas";
$locale["Group page '%s' does not exist"] =
   "Le groupe de page %s n'existe pas";
$locale["Group/User"] =
   "Groupe/Utilisateur";
$locale["Guest"] =
   "Invit";
$locale["Guests"] =
   "Invits";
$locale["H"] =
   "H";
$locale["Handles threaded topics with comments/news and provide a input form"] =
   "Contrler les sujets traits avec les commentaires/nouvelles et fournir une entre de formulaire";
$locale["HasHomePage"] =
   "APageAccueil";
$locale["Headline text"] =
   "Texte de dbut de ligne";
$locale["Height"] =
   "Hauteur";
$locale["HelloWorld"] =
   "BonjourLeMonde";
$locale["HelloWorldPlugin"] =
   "PluginBonjourLeMonde";
$locale["Here you can override site-specific default values."] =
   "Ici vous pouvez craser les valeurs par dfaut du site spcifi.";
$locale["Hide %s:"] =
   "Cacher %s :";
$locale["Hide or show LinkIcons (if supported by the current theme). Useful for text-only browsers or slow connections."] =
   "Cacher ou montrer les icnes de liens (si supportes par le thme actuel). Trs utile pour les navigateurs ne supportant pas les images ou pour les connexion bas dbit.";
$locale["History of all major and minor edits by %s to page %s."] =
   "Historique de toutes les ditions majeures et mineures par %s sur la page %s.";
$locale["History of all major and minor modifications for any page edited by %s."] =
   "Historique des ditions majeures ou mineures pour n'importe quelle page dite par %s.";
$locale["History of all major edits by %s to page %s."] =
   "Historique de toutes les ditions majeures par %s sur la page %s.";
$locale["History of changes."] =
   "Historique des changements.";
$locale["History of major modifications for any page edited by %s."] =
   "Historique des ditions majeures de toutes les pages dites par %s.";
$locale["Hit statistics"] =
   "Statistiques de visites";
$locale["Hits"] =
   "Visites";
$locale["Hits:"] =
   "Visites :";
$locale["Home"] =
   "Accueil";
$locale["HomePage"] =
   "PageAccueil";
$locale["HomePageAlias"] =
   "AliasAccueil";
$locale["Horizontal line"] =
   "Ligne horizontale";
$locale["HowToUseWiki"] =
   "CommentUtiliserWiki";
$locale["I'm just doing minor edits. Please divert the usual logging to %s instead."] =
   "Je ne fais que des modifications mineures. Veuillez rediriger les logs habituels vers %s.";
$locale["I'm sorry, there is no such page as %s."] =
   "Dsol, %s ne correspond  aucune page.";
$locale["I'm sorry.  Version %d of %s is not in the database."] =
   "Je suis dsol. La version %d de %s n'est pas dans la base de donnes.";
$locale["Ignore wiki formatting"] =
   "Ignorer le formatage wiki";
$locale["Illegal chars %s removed"] =
   "Illgal %s supprimes";
$locale["Image loaded from cache file: %s"] =
   "Image charge depuis le fichier cache : %s";
$locale["Image saved to cache file: %s"] =
   "Image sauve dans le fichier cache : %s";
$locale["In the time since you started editing this page, another user has saved a new version of it."] =
   "Depuis que vous avez commenc  diter cette page, un autre utilisateur en a enregistr une nouvelle version.";
$locale["In total there are %d user sessions online. :: Unique %d Registered and %d Guests"] =
   "Au total: %d utilisateurs en ligne. :: %d enregistr(s) et %d invit(s)";
$locale["Include an external web page within the body of a wiki page."] =
   "Inclure une page externe dans le corps de la WikiPage.";
$locale["Include of '%s' failed."] =
   "L'insertion de '%s' a chou.";
$locale["Include recursively all linked pages starting at %s"] =
   "Crer une carte du site commencer  %s";
$locale["Include text from another wiki page."] =
   "Inclure le texte d'une autre PageWiki.";
$locale["IncludePage"] =
   "InclureUnePage";
$locale["IncludePagePlugin"] =
   "PluginInclureUnePage";
$locale["IncludePages"] =
   "InclurePages";
$locale["IncludeSiteMap"] =
   "CarteDuSite";
$locale["Included from %s"] =
   "Insr de %s";
$locale["Included from %s:"] =
   "Insr de %s :";
$locale["Includes the content of all SubPages of the current page."] =
   "Pour inclure le contenu de toutes les sous pages de la page actuelle.";
$locale["Index"] =
   "Index";
$locale["Info"] =
   "Info";
$locale["Inline images"] =
   "Images intgres";
$locale["Insert non-formatted text here"] =
   "Insrer du texte non-format ici";
$locale["Insufficient permissions."] =
   "Permissions insuffisantes.";
$locale["InterWiki"] =
   "InterWiki";
$locale["InterWiki Address"] =
   "Adresse InterWiki";
$locale["InterWikiMap"] =
   "CarteInterWiki";
$locale["InterWikiSearch"] =
   "RechercheInterWiki";
$locale["Invalid ACL"] =
   "Acl invalide";
$locale["Invalid [] syntax ignored"] =
   "[] non valables, ignor";
$locale["Invalid argument: %s=%s"] =
   "Argument non valable : %s=%s";
$locale["Invalid chmod string"] =
   "Chane de caractre invalide pour le changement de mode";
$locale["Invalid color: %s"] =
   "Couleur non valable : %s";
$locale["Invalid image size"] =
   "Taille d'image non valables";
$locale["Invalid password or userid."] =
   "Mot de passe ou identifiant d'utilisateur invalide.";
$locale["Invalid password."] =
   "Mauvais mot de passe.";
$locale["Invalid username '%s' for LDAP Auth"] =
   "Mot de identifiant d'utilisateur '%s' pour LDAP Auth invalide.";
$locale["Invalid username."] =
   "Mot de identifiant d'utilisateur invalide.";
$locale["Italic text"] =
   "Texte en italique";
$locale["JabberPresence"] =
   "JabberPresence";
$locale["Keep up to %d major edits, but keep them no longer than %d days."] =
   "Garder jusqu' %d dition majeures, mais pas plus que %d jours.";
$locale["Language"] =
   "Langage";
$locale["Last"] =
   "Dernire";
$locale["Last Author"] =
   "Dernier auteur";
$locale["Last Modified"] =
   "Dernire Modification";
$locale["Last Summary"] =
   "Dernier rsum";
$locale["Last edited %s"] =
   "Dernire modification %s";
$locale["Last edited on %s"] =
   "Dernire modification le %s";
$locale["LatestSnapshot"] =
   "DernierInstantan";
$locale["Layout tables using a very rich markup style."] =
   "Un systme de marques pour faire des tableaux sophistiqus.";
$locale["Layout tables using the old markup style."] =
   "Apparences de tableaux utilisant l'ancien modle de balisage.";
$locale["LdapSearch"] =
   "LdapChercher";
$locale["Leading %s not allowed"] =
   "Mener %s n'est pas permis";
$locale["Legend"] =
   "Lgende";
$locale["Level 1 headline"] =
   "Texte de dbut de ligne de niveau 1";
$locale["Like Pages"] =
   "PagesSemblables";
$locale["LikePages"] =
   "PagesSemblables";
$locale["Line %s does not begin with a '|'."] =
   "La ligne %s ne commence pas par un '|'.";
$locale["Link to page"] =
   "Lien vers la page";
$locale["LinkDatabase"] =
   "LiensDatabase";
$locale["LinkIcons"] =
   "IcnesLiens";
$locale["Links"] =
   "Liens";
$locale["List PageHistory for %s"] =
   "Historique de %s";
$locale["List all once authenticated users."] =
   "numrez tous les utilisateurs une fois authentifis.";
$locale["List all page revisions edited by one user with diff links, or show a PageHistory-like list of a single page for only one user."] =
   "Affiche la liste de toutes les rvisions faites par un auteur, ou montre une liste du type HistoriquePage pour une simple page uniquement pour un auteur.";
$locale["List all pages in this wiki."] =
   "Afficher la liste de toutes les pages de ce wiki.";
$locale["List all pages which link to %s."] =
   "Affiche toutes les pages lie  %s.";
$locale["List all pages."] =
   "Liste de toutes les pages.";
$locale["List of pages created by [%s] (%d total):"] =
   "Liste des pages cr prs [%s] (%d au total) :";
$locale["List of pages last edited by [%s] (%d total):"] =
   "Liste des pages bout dit prs [%s] (%d au total) :";
$locale["List of pages owned by [%s] (%d total):"] =
   "Liste des pages possd prs [%s] (%d au total) :";
$locale["List page names which share an initial or final title word with '%s'."] =
   "Affiche la liste des pages qui partagent un mot initial ou final dans leur titre avec %s.";
$locale["List pages that are explicitly given as the pages argument."] =
   "Liste des pages qui sont explicitement donnes en argument.";
$locale["List pages which are not linked to by any other page."] =
   "Liste des pages qui ne sont lies  aucune autre.";
$locale["List the most popular pages nearby."] =
   "numre les pages proches des plus visites.";
$locale["List the most popular pages."] =
   "Affiche la listes des pages les plus populaires.";
$locale["List this page and all subpages"] =
   "Lister cette page et ses sous-pages";
$locale["ListPages"] =
   "ListeDePages";
$locale["ListSubpages"] =
   "ListeDesSousPages";
$locale["Lists referenced page names which do not exist yet."] =
   "Afficher toutes les pages rfrences qui n'existent pas.";
$locale["Lists the names of all SubPages of the current page."] =
   "Affiche la liste des noms de toutes les sous-pages de la page courante.";
$locale["LiveSearch"] =
   "RechercheLive";
$locale["Load File"] =
   "Charger le fichier";
$locale["Loading '%s'"] =
   "Chargement ' %s '";
$locale["Loading InterWikiMap from external file %s."] =
   "Chargement de la CarteInterWiki depuis le fichiers %s.";
$locale["Loading files"] =
   "Chargement des fichiers";
$locale["Loading up virgin wiki"] =
   "Chargement d'un wiki vierge";
$locale["Lock"] =
   "Verrouille";
$locale["Lock Page"] =
   "Vrrouiller la page";
$locale["Lock page to enable link"] =
   "Verrouillez la page pour permettre le lien";
$locale["Locked"] =
   "Verrouille";
$locale["Locking pages"] =
   "Verrouillage des pages";
$locale["Login"] =
   "Identifiant";
$locale["MIME file %s"] =
   "fichier MIME %s";
$locale["MISSING"] =
   "MANQUANT";
$locale["MagicPhpWikiURLs"] =
   "URLMagiquesPhpWiki";
$locale["Make use of the Google API"] =
   "Faire usage de l'API Google";
$locale["Markup"] =
   "Marquage";
$locale["Markup cache purged!"] =
   "Cache de marques purg !";
$locale["Markup:"] =
   "Balises :";
$locale["Members:"] =
   "Membres :";
$locale["Merge Edit"] =
   "Fusionner l'dition";
$locale["Merge and Edit: %s"] =
   "Fusioner et diter : %s";
$locale["Message"] =
   "Message";
$locale["Method '%s' not implemented in this GROUP_METHOD %s"] =
   "La mthode '%s' n'est pas implmente dans ce GROUP_METHOD (%s)";
$locale["Minor"] =
   "Mineure";
$locale["Minor Edit"] =
   "dition Mineure";
$locale["Miscellaneous utility functions for the Administrator."] =
   "Plusieurs fonctions pour l'administration d'un wiki.";
$locale["Missing %s for %s"] =
   "Il manque %s pour %s";
$locale["Missing PagePermission:"] =
   "Permission de page individuelle absente:";
$locale["ModeratedPage"] =
   "PageModre";
$locale["ModeratedPage Notification Error: Couldn't send email"] =
   "Erreur lors des notifications de page: Impossible d'envoyer";
$locale["ModeratedPage: No emails for the moderators defined"] =
   "PageModere: No emails for the moderators defined";
$locale["Modern"] =
   "Moderne";
$locale["Modified"] =
   "Dernire modification";
$locale["Moniker"] =
   "Nom";
$locale["MoreAboutMechanics"] =
   "DtailsTechniques";
$locale["Most users ever online was %d at %s."] =
   "Record du nombre d'utilisateur: %d le %s.";
$locale["MostPopular"] =
   "LesPlusVisites";
$locale["Name"] =
   "Nom";
$locale["Never edited"] =
   "Jamais dite";
$locale["New Topic"] =
   "Nouveau sujet";
$locale["New comment."] =
   "Nouveau commentaire.";
$locale["New page"] =
   "Nouvelle page";
$locale["New password"] =
   "Nouveau mot de passe";
$locale["New users may use an empty password."] =
   "Les nouveaux utilisateurs devraient utiliser un mot de passe vide.";
$locale["NewMarkupTestPage"] =
   "PageTestNouvellesMarques";
$locale["Newer page:"] =
   "Page rcente :";
$locale["Next"] =
   "Suivant";
$locale["Next Month"] =
   "Mois suivant";
$locale["No DSN alias for SqlResult.ini specified"] =
   "Aucun alias DSN spcifi pour SqlResult.ini";
$locale["No DSN for alias %s in SqlResult.ini found"] =
   "Aucun alias DSN trouv pour %s dans SqlResult.ini";
$locale["No LDAP in this PHP version"] =
   "Pas de LDAP dans cette version de php";
$locale["No changes found"] =
   "Aucun commentaire trouv";
$locale["No changes."] =
   "Aucun changement.";
$locale["No comments found"] =
   "Aucune diffrence trouve";
$locale["No empty, unreferenced pages were found."] =
   "Aucune page trouve avec un nom invalide.";
$locale["No or not enough GROUP_DB SQL statements defined"] =
   "Aucun ou pas assez de GROUP_DB dfinis pour SQL";
$locale["No or unsupported GROUP_METHOD defined"] =
   "Aucun GROUP_METHOD dfini, ou GROUP_METHOD non support";
$locale["No other page links to %s yet."] =
   "Aucune page n'est ancore lie  %s.";
$locale["No page links to %s."] =
   "Aucune page ne pointe vers %s.";
$locale["No pagedata for %s"] =
   "Pas de donnes de page pour %s";
$locale["No pagename specified"] =
   "Aucun nom de page indiqu";
$locale["No pages changed."] =
   "Aucune page change.";
$locale["No pages renamed."] =
   "Aucune page renomme.";
$locale["No pages with bad names had to be deleted."] =
   "Aucune page supprimes avec un nom invalide.";
$locale["No revisions found"] =
   "Rvision Non Trouve";
$locale["No uploaded file to upload?"] =
   "Pas de fichier  dposer ?";
$locale["No userid"] =
   "Pas d'identifiant utilisateur";
$locale["NoCache"] =
   "PasDeCache";
$locale["None"] =
   "Aucune";
$locale["Not enough questions answered!"] =
   "Pas assez de rponses fournies !";
$locale["Note that many browsers will automatically adjust the width of the editing area so that it fills the browser window.  In this case, the width preference will be ignored."] =
   "Notez que beaucoup de navigateurs ajusteront automatiquement la largeur de la zone d'dition de faon qu'elle remplisse la fentre. Le paramtre concernant la largeur sera ignor dans ce cas.";
$locale["Note, that user accounts with bouncing emails will be disabled."] =
   "Notez que les comptes utilisateurs dont l'adresse e-mail est inexistante seront dsactivs.";
$locale["Note:"] =
   "Note :";
$locale["Note: Only if you create your personal HomePage with same the pagename as your user id, you will be able to store your UserPreferences. Otherwise not."] =
   "Note: Vous pourrez enregistrer vos PrfrencesUtilisateurs uniquement si vous crez votre propre page d'accueil portant le nom de votre identifiant.";
$locale["Nothing found"] =
   "Aucun rsultat";
$locale["OK"] =
   "OK";
$locale["Ok"] =
   "Ok";
$locale["Okay"] =
   "OK";
$locale["Old UserPage %s without stored password updated with empty password. Set a password in your UserPreferences."] =
   "L'anciene page %s sans mot de passe attribu a t mise  jour avec un mot de passe vide. Dfinissez un mot de passe dans vos PrfrencesUtilisateurs.";
$locale["OldMarkupTestPage"] =
   "PageTestAnciennesMarques";
$locale["OldStyleTable"] =
   "TableauAncienStyle";
$locale["OldStyleTablePlugin"] =
   "PluginTableauAncienStyle";
$locale["OldTextFormattingRules"] =
   "RglesDeFormatageDesTextes";
$locale["Older page:"] =
   "Ancienne page :";
$locale["One page links to %s:"] =
   "Une page pointe vers %s :";
$locale["One page would link to %s:"] =
   "Une page pointait vers %s :";
$locale["Oops! Revision %s of %s seems to have been deleted!"] =
   "Ouille ! La rvision %s de %s semble avoir t efface !";
$locale["Optimizing database"] =
   "Optimisation de database";
$locale["Original (1.2 or 1.0)"] =
   "Original (1.2 ou 1.0)";
$locale["Orphaned Pages in this wiki (%d total):"] =
   "Pages Orphelines dans ce wiki (%d au total) :";
$locale["OrphanedPages"] =
   "PagesOrphelines";
$locale["Other diffs:"] =
   "Autres comparaisons :";
$locale["Other version"] =
   "L'autre version";
$locale["Our users created a total of %d pages."] =
   "Nos utilisateurs ont crs un total de %s pages.";
$locale["Owner"] =
   "Propritaire";
$locale["Owner: %s"] =
   "Propritaire: %s";
$locale["PHP syntax highlighting"] =
   "Coloration syntaxique du PHP";
$locale["PHP was unable to create a new GD image stream. Read 'lib/plugin/text2png.php' for details."] =
   "PHP n'a pas pu crer un nouveau flux d'image GD. Lisez 'lib/plugin/text2png.php' pour plus de dtails.";
$locale["Page %s already exists. Ignored."] =
   "La page %s existe dj. Ignor.";
$locale["Page %s not found."] =
   "Page %s non trouve.";
$locale["Page Content: "] =
   "Contenu de la page : ";
$locale["Page Execution took %s seconds"] =
   "L'excution de la page a pris %s seconds";
$locale["Page Locked"] =
   "Page Verrouille";
$locale["Page Name"] =
   "Nom de la page";
$locale["Page Trail"] =
   "Trace Page";
$locale["Page Type:"] =
   "Type de Page :";
$locale["Page Version:"] =
   "Version de la Page :";
$locale["Page names with prefix '%s'"] =
   "Noms de page ayant le prfixe ' %s '";
$locale["Page names with suffix '%s'"] =
   "Noms de page ayant le suffixe ' %s '";
$locale["Page now locked."] =
   "La page est maintenant verrouille.";
$locale["Page now unlocked."] =
   "La page est maintenant dverrouille.";
$locale["Page removed %s"] =
   "Page enleve %s";
$locale["Page rename %s to %s"] =
   "retitrez la page de '%s'  '%s'";
$locale["Page statistics"] =
   "Statistiques de page";
$locale["Page successfully updated."] =
   "Page chang avec succs.";
$locale["PageChange Notification Error: Couldn't send %s to %s"] =
   "Erreur lors des notifications de changements de page: Impossible d'envoyer %s  %s";
$locale["PageChange Notification of %s sent to %s"] =
   "Les notifications de changement de la page %s ont t envoys  %s";
$locale["PageDump"] =
   "RcuprationDeLaPage";
$locale["PageGroup"] =
   "GroupeDePages";
$locale["PageGroup for %s"] =
   "Groupe de pages pour %s";
$locale["PageGroupTest"] =
   "TestGroupeDePages";
$locale["PageGroupTest/Four"] =
   "TestGroupeDePages/Quatre";
$locale["PageGroupTest/One"] =
   "TestGroupeDePages/Un";
$locale["PageGroupTest/Three"] =
   "TestGroupeDePages/Trois";
$locale["PageGroupTest/Two"] =
   "TestGroupeDePages/Deux";
$locale["PageHistory"] =
   "HistoriqueDeLaPage";
$locale["PageHistory for %s"] =
   "Historique de %s";
$locale["PageInfo"] =
   "InfosSurLaPage";
$locale["PageTrail"] =
   "TracePage";
$locale["PageTrail Plugin"] =
   "Pour suivre les pages  la trace";
$locale["Pagedata size: %d Kb"] =
   "Taille des donnes de la page : %d Kb";
$locale["Password cannot be changed."] =
   "Mot de passe inchangeable.";
$locale["Password updated."] =
   "Mot de passe mis  jour.";
$locale["Password was not changed."] =
   "Mot de passe inchang.";
$locale["Password:"] =
   "Mot de passe :";
$locale["Perform searches on InterWiki sites listed in InterWikiMap."] =
   "Effectuer une recherche sur les sites InterWiki contenu dans la carte InterWiki.";
$locale["Permanently remove all selected pages."] =
   "Supprimer toutes les pages slectionnes en permanence.";
$locale["Permanently remove the selected files:"] =
   "Supprimer dfinitivement les fichiers slectionns :";
$locale["Permission"] =
   "Permission";
$locale["Personal Auth Settings for '%s'"] =
   "Prfrences personnelles pour '%s'";
$locale["Personal language:"] =
   "Langage personnel :";
$locale["Personal theme:"] =
   "Thme personnel :";
$locale["PgsrcTranslation"] =
   "TraductionPgsrc";
$locale["PgsrcTranslation/de"] =
   "TraductionPgsrc/de";
$locale["PgsrcTranslation/es"] =
   "TraductionPgsrc/es";
$locale["PgsrcTranslation/fr"] =
   "TraductionPgsrc/fr";
$locale["PgsrcTranslation/it"] =
   "TraductionPgsrc/it";
$locale["PgsrcTranslation/ja"] =
   "TraductionPgsrc/ja";
$locale["PgsrcTranslation/nl"] =
   "TraductionPgsrc/nl";
$locale["PgsrcTranslation/sv"] =
   "TraductionPgsrc/sv";
$locale["PgsrcTranslation/zh"] =
   "TraductionPgsrc/zh";
$locale["PhotoAlbum"] =
   "AlbumPhotos";
$locale["PhotoAlbumPlugin"] =
   "PluginAlbumPhotos";
$locale["Photos"] =
   "Photos";
$locale["PhpHighlight"] =
   "ColorationPhp";
$locale["PhpHighlightPlugin"] =
   "PluginColorationPhp";
$locale["PhpWeather"] =
   "MtoPhp";
$locale["PhpWeatherPlugin"] =
   "PluginMtoPhp";
$locale["PhpWiki"] =
   "PhpWiki";
$locale["PhpWiki developers should manually inspect the downloaded file for nested markup before rewrapping with emacs and checking into CVS."] =
   "Les dveloppeurs de PhpWiki devraient inspecter manuellement les balises des fichiers tlchargs avant de les diter sous emacs, et vrifier les CVS.";
$locale["PhpWiki engine version"] =
   "Version de PhpWiki";
$locale["PhpWikiAdministration"] =
   "AdministrationDePhpWiki";
$locale["PhpWikiAdministration/Chmod"] =
   "AdministrationDePhpWiki/Chmod";
$locale["PhpWikiAdministration/Chown"] =
   "AdministrationDePhpWiki/Chown";
$locale["PhpWikiAdministration/Remove"] =
   "AdministrationDePhpWiki/Supprimer";
$locale["PhpWikiAdministration/Rename"] =
   "AdministrationDePhpWiki/Renommer";
$locale["PhpWikiAdministration/Replace"] =
   "AdministrationDePhpWiki/Remplacer";
$locale["PhpWikiAdministration/SetAcl"] =
   "AdministrationDePhpWiki/DfinirAcl";
$locale["PhpWikiDocumentation"] =
   "DocumentationDePhpWiki";
$locale["PhpWikiPoll"] =
   "SondagePhpWiki";
$locale["Please check it through before saving."] =
   "Veuillez la vrifier avant de la sauver.";
$locale["Please contact your PhpWiki administrator for assistance."] =
   "Veuillez contacter l'administrateur pour l'assistance.";
$locale["Please continue editing.  (You'll find your %s at the bottom of the page.)"] =
   "Veuillez continuer votre dition. (Vous trouverez votre %s en bas de page).";
$locale["Please ensure that %s is writable, or redefine %s in config/config.ini."] =
   "Veuillez vous assurer que %s est disponible en criture, ou redfinissez-le dans config/config.ini.";
$locale["Please set ENCRYPTED_PASSWD to false in config/config.ini and probably change ADMIN_PASSWD."] =
   "Veuillez dfinir ENCRYPTED_PASSWD  false dans config/config.ini et probablement l'ADMIN_PASSWD.";
$locale["Please set ENCRYPTED_PASSWD to true in config/config.ini."] =
   "Veuillez dfinir ENCRYPTED_PASSWD  true dans config/config.ini.";
$locale["Please set a password in UserPreferences."] =
   "Veuillez dfinir votre mot de passe dans PrfrencesUtilisateurs.";
$locale["Please use one of the downloadable versions rather than copying and pasting from the above preview."] =
   "Veuillez utiliser une des versions tlchargeables au lieu de copier-coller  partir de la prvisualisation.";
$locale["PloticusPlugin"] =
   "PluginPloticus";
$locale["Plugin"] =
   "Plugin";
$locale["Plugin %s disabled."] =
   "Plugin %s dsactiv.";
$locale["Plugin %s failed."] =
   "Plugin %s a chou.";
$locale["Plugin %s: undefined"] =
   "Plugin %s: non dfini";
$locale["PluginManager"] =
   "GestionsDesPlugins";
$locale["Plugins"] =
   "Plugins";
$locale["PopularNearby"] =
   "PopulairesAlentour";
$locale["Post new"] =
   "Poster un nouveau";
$locale["Posted: %s"] =
   "Post le %s";
$locale["Preferences"] =
   "Prfrences";
$locale["PreferencesInfo"] =
   "PrfrencesInfo";
$locale["PrevNext"] =
   "PrcdentSuivant";
$locale["Preview"] =
   "Prvisualiser";
$locale["Preview as backup format"] =
   "Prvisualisation au format de sauvegarde";
$locale["Preview as developer format"] =
   "Prvisualisation au format dveloppeurs";
$locale["Preview only!  Changes not saved."] =
   "Prvisualisation uniquement ! Modifications non enregistres.";
$locale["Preview: Page dump of %s"] =
   "Prvisualisation : rcupration de %s";
$locale["Previous"] =
   "Prcdent";
$locale["Previous Author"] =
   "Auteur Prcdent";
$locale["Previous Major Revision"] =
   "Prcdente Rvision Principale";
$locale["Previous Month"] =
   "Mois prcdent";
$locale["Previous Revision"] =
   "Rvision Prcdente";
$locale["Printer"] =
   "Imprimante";
$locale["Propagate new permissions to all subpages?"] =
   "Propager les nouvelles permissions aux sous-pages ?";
$locale["Provides access to PhpWiki's lower level system information."] =
   "Affiche les informations de bas niveau pour PhpWiki.";
$locale["Purge HTML cache for this page. Regenerate from WikiMarkup when next accessed."] =
   "Purge le cache HTML pour cette page. Rgnre depuis WikiMarkup lors du prochain accs.";
$locale["Purge Markup Cache"] =
   "Purger le cache";
$locale["Purge all Pages With Invalid Names"] =
   "Supprimer les pages dont le nom n'est pas valide";
$locale["PurgeHtmlCache"] =
   "PurgerLeCache";
$locale["Querying backend directly for '%s'"] =
   "Requte directe au backend pour '%s'";
$locale["Quick Search"] =
   "Recherche Rapide";
$locale["RandomPage"] =
   "PageAlatoire";
$locale["Rate"] =
   "Note";
$locale["Rate It"] =
   "Classez la";
$locale["Rate the topic of this page"] =
   "Notez les sujets de cette page";
$locale["RateIt"] =
   "ClassezLa";
$locale["Rated by %d users | Average rating %.1f stars"] =
   "Not par %d utilisateurs | Moyenne des notes %.1f toiles.";
$locale["Rating system. Store user ratings per page"] =
   "Systme de vote. Stocke les votes d'utilisateur par page.";
$locale["Raw HTML"] =
   "HTML Pur";
$locale["Raw HTML is disabled in this wiki."] =
   "Le HTML est interdit sur ce wiki.";
$locale["RawHtmlPlugin"] =
   "PluginHtmlPur";
$locale["Recent Comments"] =
   "Commentaires rcents";
$locale["Recent Edits"] =
   "ditions Rcentes";
$locale["RecentChanges"] =
   "DerniresModifs";
$locale["RecentComments"] =
   "CommentairesRcents";
$locale["RecentEdits"] =
   "ditionsRcentes";
$locale["RecentVisitors"] =
   "VisiteursRcents";
$locale["Recursive redirect to self: '%s'"] =
   "Redirection rcursive vers soi-mme: %s";
$locale["Recursively get BackLinks or links"] =
   "Obtenir rcursivement des RtroLiens ou liens";
$locale["Redirect"] =
   "Redirection";
$locale["Redirect to an external url"] =
   "Redirige vers une url d'un site extrieur";
$locale["RedirectTo"] =
   "RedirigerVers";
$locale["RedirectToPlugin"] =
   "PluginRedirection";
$locale["Redirects to an external web site based on form input"] =
   "Redirige vers un site externe bas sur un formulaire";
$locale["Redirects to another url or page."] =
   "Redirige vers une autre url ou page.";
$locale["References"] =
   "Rfrences";
$locale["Regex?"] =
   "expression rgulire ?";
$locale["Registered Users"] =
   "Utilisateurs Enregistrs";
$locale["Registered Users Online: "] =
   "Utilisateurs enregistrs en ligne : ";
$locale["Related Changes"] =
   "Changements lis";
$locale["Related Links"] =
   "Liens correspondants";
$locale["RelatedChanges"] =
   "ChangementsLis";
$locale["ReleaseNotes"] =
   "NotesDeVersion";
$locale["Remove"] =
   "Supprimer";
$locale["Remove Page"] =
   "Supprimer la page";
$locale["Remove Preferences"] =
   "Effacer les prfrences";
$locale["Remove selected pages"] =
   "Supprimer les pages slectionnes";
$locale["Remove this page"] =
   "Supprimer la page";
$locale["Removed by: %s"] =
   "Enlev prs : %s";
$locale["Removed page '%s' successfully."] =
   "Page '%s' supprime avec succs.";
$locale["Removing pages"] =
   "Suppression des pages";
$locale["Rename"] =
   "Renommer";
$locale["Rename selected pages"] =
   "Renommer les pages slectionnes.";
$locale["Rename to"] =
   "Renommer en";
$locale["Renamed page '%s' to '%s'."] =
   "Page '%s' renommes en '%s' avec succs.";
$locale["Replace with"] =
   "Remplacer par";
$locale["Replace: "] =
   "Remplacer: ";
$locale["Replaced '%s' with '%s' in page '%s'."] =
   "%s a bien t modifi par %s dans la page %s.";
$locale["Reply"] =
   "Rpondre";
$locale["Requires WikiAdmin privileges to edit."] =
   "Ncessite les privilges administrateur pour l'dition.";
$locale["Reset"] =
   "Rinitialiser";
$locale["Restore Anyway"] =
   "Restaurer quand mme";
$locale["Return to %s"] =
   "Retour  la %s";
$locale["Revert"] =
   "Rinitialiser";
$locale["Revision Not Found"] =
   "Rvision Non Trouve";
$locale["RichTable"] =
   "BeauTableau";
$locale["RichTablePlugin"] =
   "PluginBeauTableau";
$locale["RssFeed"] =
   "RessourcesRss";
$locale["SOAP access"] =
   "Accs SOAP";
$locale["SandBox"] =
   "BacSable";
$locale["Save"] =
   "Enregistrer";
$locale["Saved on:"] =
   "Enregistre le :";
$locale["Saved: %s"] =
   "Enregistre : %s";
$locale["Saving this page will overwrite the current version."] =
   "Enregistrer cette page crasera la version actuelle.";
$locale["Score"] =
   "Point";
$locale["Search"] =
   "Chercher";
$locale["Search & Replace"] =
   "Recherche & Remplace";
$locale["Search and replace text in selected wiki pages."] =
   "Recherche puis remplace le texte dans les pages slectionnes.";
$locale["Search for page titles similar to %s."] =
   "Rechercher le titre de page similaire  %s.";
$locale["Search string '%s' not found in content of page '%s'."] =
   "La chane '%s' ne se trouve pas dans la page '%s'.";
$locale["Search the content of all pages in this wiki."] =
   "Rechercher le contenu de toutes les pages de ce wiki.";
$locale["Search the titles of all pages in this wiki."] =
   "Rechercher les titres de toutes les pages de ce wiki.";
$locale["See %s"] =
   "Voir %s";
$locale["See %s tips for editing."] =
   "Voir les conseils pour diter les pages dans %s.";
$locale["See: %s"] =
   "Voir : %s";
$locale["Select"] =
   "Slectionner";
$locale["Select pages"] =
   "Slectionner les pages";
$locale["Select the pages to change the owner:"] =
   "Slectionnez les pages qui vont chnager de propritaire :";
$locale["Select the pages to change:"] =
   "Slectionnez les pages  modifier :";
$locale["Select the pages to rename:"] =
   "Slectionner les pages  renommer :";
$locale["Select the pages to search:"] =
   "Slectionner ci-dessous les pages dans lesquelles la recherche sera effectue :";
$locale["Select: "] =
   "Slectionner : ";
$locale["Selected Grant checkboxes allow access, unselected checkboxes deny access."] =
   "Les cases slectionnes autorisent l'accs, sinon elles l'interdisent.";
$locale["Selected Pages: "] =
   "Pages slectionnes : ";
$locale["Selected page '%s' passed to '%s'."] =
   "%s passe  %s.";
$locale["Serialized file %s"] =
   "Fichier srialis %s";
$locale["Set Password"] =
   "Mot de passe";
$locale["Set USE_DB_SESSION to false."] =
   "Mettre USE_DB_SESSION  false.";
$locale["Set individual page permissions."] =
   "Rgler les permissions de pages individuellement.";
$locale["SetAcl"] =
   "DfinirAcl";
$locale["Show all changes for:"] =
   "Indiquer toutes les modifications pour :";
$locale["Show and add blogs for %s"] =
   "Montrer et ajouter un Blog  %s ";
$locale["Show and add comments for %s"] =
   "Afficher et ajouter des commentaires pour %s";
$locale["Show changes for:"] =
   "Indiquer les modifications pour :";
$locale["Show extra page Info and statistics for %s."] =
   "Montrer les informations de la page %s ainsi que ses statistiques.";
$locale["Show minor edits for:"] =
   "Afficher les ditions mineures pour :";
$locale["Show relative dates using 'Today' and 'Yesterday'"] =
   "Montre les dates relatives en utilisant 'Aujourd'hui' et 'Hier'.";
$locale["Show summary information from the access log table."] =
   "Montre l'index de la table access log.";
$locale["Show summary information of the current user sessions."] =
   "Montre l'index de la table session. (utilisateurs en ligne).";
$locale["Show translations of various words or pages"] =
   "Affiche la traduction de quelques mots dans certaines pages.";
$locale["Sidebar"] =
   "Barre verticale";
$locale["Sign In"] =
   "Connexion";
$locale["Sign Out"] =
   "Dconnexion";
$locale["Sign in as:"] =
   "Se connecter en tant que :";
$locale["SignIn"] =
   "Connexion";
$locale["SignOut"] =
   "Dconnexion";
$locale["Signed Users"] =
   "Utilisateurs signs";
$locale["Signed as %s"] =
   "Connect comme %s";
$locale["Simple RSS Feed aggregator Plugin"] =
   "Importer des ressources RSS";
$locale["Simple Sample Plugin"] =
   "Exemple simple de Plugin";
$locale["Since you started the deletion process, someone has saved a new version of %s.  Please check to make sure you still want to permanently remove the page from the database."] =
   "Depuis que vous avez entam le processus d'effacement, quelqu'un a enregistr une nouvelle version de %s. Veuillez vrifier que vous dsirez toujours retirer de faon permanente cette page de la base de donnes.";
$locale["SiteMap"] =
   "CarteDuSite";
$locale["Size"] =
   "Taille";
$locale["Size:"] =
   "Taille :";
$locale["Skipped."] =
   "Ignor.";
$locale["Skipping"] =
   "Ignor";
$locale["Some of the changes could not automatically be combined.  Please look for sections beginning with '%s', and ending with '%s'.  You will need to edit those sections by hand before you click Save."] =
   "Certaines modifications n'ont pas pu tre combines automatiquement. Veuillez regarder les sections commenant par '%s', et se terminant par '%s'. Vous devrez diter ces sections  la main avant cliquer sur Enregistrer.";
$locale["Someone has edited the page!"] =
   "Quelqu'un a dit la page !";
$locale["Sorry but this file is too big."] =
   "Dsol, mais le fichier est trop gros.";
$locale["Sorry for the inconvenience."] =
   "Dsol pour la gne occasionne.";
$locale["Sorry! You must wait at least 20 minutes until you can vote again!"] =
   "Dsol, vous devez attendre au moins 20 minutes avant de pouvoir revoter !";
$locale["Sorry, no dynamic DB Session support."] =
   "Dsol, Session dynamique non supportes.";
$locale["Sorry, this page is not in the database."] =
   "Je suis dsol. Cet page n'est pas dans la base de donnes.";
$locale["Sorry, this version of PHP cannot create PNG image files."] =
   "Dsol, cette version de PHP ne peut pas crer des fichiers d'image PNG.";
$locale["Sorry. Access Restrictions not yet implemented"] =
   "Dsol. Restriction d'accs pas encore disponible";
$locale["Sort by %s"] =
   "Tri par %s";
$locale["Sound Score"] =
   "Score de son";
$locale["Spelling Score"] =
   "Score d'pellation";
$locale["SqlResult"] =
   "RsultatSql";
$locale["Statistics about %s."] =
   "Statistiques sur %s.";
$locale["Status:"] =
   "Statut :";
$locale["SteveWainstead"] =
   "SteveWainstead";
$locale["String \"%s\" not found."] =
   "\"%s\" non trouve.";
$locale["SubPages of %s:"] =
   "SousPages de %s :";
$locale["Submit"] =
   "Valider";
$locale["Submit country"] =
   "Valider le pays";
$locale["Submit location"] =
   "Valider la localisation";
$locale["Subpage"] =
   "Sous-page";
$locale["Summary"] =
   "Rsum";
$locale["Supplanted on:"] =
   "Remplace le :";
$locale["Support moderated pages"] =
   "Supports pages modere";
$locale["Supported handlers are: %s"] =
   "Les gestionnaires supports sont : %s";
$locale["Supported languages"] =
   "Langages supports";
$locale["Supported themes"] =
   "Thmes supports";
$locale["Switch to detailed list"] =
   "Passer  la liste dtaille";
$locale["Switch to summary"] =
   "Passer au Sommaire";
$locale["Synopsis"] =
   "Vue d'ensemble";
$locale["Syntax language not specified."] =
   "Syntaxe du langage non spcifi.";
$locale["SyntaxHighlighter"] =
   "ColorationSyntaxique";
$locale["System default:"] =
   "Systme par dfaut :";
$locale["SystemInfo"] =
   "InfosSystme";
$locale["SystemInfoPlugin"] =
   "PluginInfosSystme";
$locale["TODO: Google can only translate from english and french. Find a translation service for %s to language %s"] =
   "A FAIRE: Google peut uniquement traduire l'anglais et le franais. Trouver un service pour traduire %s en %s";
$locale["Table Of Contents"] =
   "Table des matires";
$locale["TeX directory not writable."] =
   "Rpertoire TeX non accessible en criture.";
$locale["TeX2png"] =
   "TeX2png";
$locale["TextFormattingRules"] =
   "RglesDeFormatageDesTextes";
$locale["Thank you for editing %s."] =
   "Merci d'avoir dit %s.";
$locale["Thanks for adding this translation!"] =
   "Merci d'avoir ajout cette traduction.";
$locale["Thanks for participating!"] =
   "Merci d'avoir particip !";
$locale["The %d least popular pages of this wiki:"] =
   "Les %d pages les moins populaires de ce wiki :";
$locale["The %d most popular pages of this wiki:"] =
   "Les %d pages les plus populaires de ce wiki :";
$locale["The %d most recent %s are listed below."] =
   "Les %d %s les plus rcentes sont listes ci-dessous.";
$locale["The %d most recent %s during the past %s days are listed below."] =
   "Les %d %s les plus rcentes pendant les derniers %s jours sont listes ci-dessous.";
$locale["The %d most recent %s during the past day are listed below."] =
   "Les %d %s les plus rcentes pendant le dernier jour sont listes ci-dessous.";
$locale["The %d oldest %s are listed below."] =
   "Les %d %s les plus anciennes sont listes ci-dessous.";
$locale["The %d oldest %s during the past %s days are listed below."] =
   "Les %d %s les plus anciennes pendant les derniers %s jours sont listes ci-dessous.";
$locale["The %d oldest %s during the past day are listed below."] =
   "Les %d %s les plus anciennes pendant le dernier jour sont listes ci-dessous.";
$locale["The %s files are in the %s directory. Please read the INSTALL file and move the database to a permanent location or risk losing all the pages!"] =
   "Les fichiers %s sont dans le rpertoire %s. Veuillez lire le fichier INSTALL et dplacez le fichier DB vers un emplacement permanent, sinon vous risquez de perdre toutes vos pages !";
$locale["The %s subpage enables simple weblogging."] =
   "Les sous pages de %s permettent le simple weblogging.";
$locale["The DBA handler %s is unsupported!"] =
   "Le gestionnaire DBA %s n'est pas support !";
$locale["The ICAO '%s' wasn't recognized."] =
   "L'ICAO '%s' n'a pas t reconnu.";
$locale["The PhpWeather plugin provides weather reports from the Internet."] =
   "Le plugin de mto importe d'internet.";
$locale["The PhpWiki access log file"] =
   "Le journal d'vnement de PhpWiki";
$locale["The PhpWiki programming team"] =
   "L'quipe de dveloppement de PhpWiki";
$locale["The crypt function is not available in this version of PHP."] =
   "La fonction de cryptage n'est pas disponible dans cette version de PHP.";
$locale["The current page has no subpages defined."] =
   "La page actuelle n'a aucune sous-page dfinie.";
$locale["The current time at the server is %s."] =
   "L'heure actuelle du serveur est %s.";
$locale["The length of the stored password is shorter than the system policy allows. Sorry, you cannot login.\n You have to ask the System Administrator to reset your password."] =
   "La taille de votre mot de passe est trop petite, vous ne pouvez pas vous connecter. Veuillez contacter l'administrateur pour le changer.";
$locale["The most recent %s during the past %s days are listed below."] =
   "Les %s les plus rcentes pendant les derniers %s jours sont listes ci-dessous.";
$locale["The most recent %s during the past day are listed below."] =
   "Les %s les plus rcentes pendant le dernier jour sont listes ci-dessous.";
$locale["The newest registered user is %s."] =
   "L'utilisateur enregistr le plus rcent est %s.";
$locale["The result of this poll so far:"] =
   "Le rsultat du sondage :";
$locale["The session.save_path directory"] =
   "Le rpertoire 'session.save_path'";
$locale["The upload logfile is not writable."] =
   "Erreur : le journal des dpts n'est pas disponible en criture.";
$locale["The wordwrap of the preview doesn't take nested markup or list indentation into consideration!"] =
   "Le retour chariot de la prvisualisation ne prend pas en compte les marques des listes indentes !";
$locale["Theme"] =
   "Thme";
$locale["There is already a file with name %s uploaded."] =
   "Un fichier portant le nom '%s' existe dj.";
$locale["There is no image creation data available to id '%s'. Please reload referring page."] =
   "Aucune image ne correspond  l'id %s. Veuillez recharger cette page.";
$locale["These page titles match fuzzy with '%s'"] =
   "Ces titres de pages correspondent de manire floue  '%s'";
$locale["These pages share an initial or final title word with '%s'"] =
   "Ces pages partagent un mot initial ou final dans leur titre avec %s";
$locale["This data is based on users active over the past %s."] =
   "Ces donnes sont bases sur les utilisateurs actifs depuis %s.";
$locale["This internal action page cannot viewed."] =
   "Cette page ne peut tre vue.";
$locale["This is a minor change."] =
   "Modification mineure.";
$locale["This page already exists"] =
   "Cette page existe dj";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Cette page a t verrouille par l'administrateur et ne peut pas tre modifie.";
$locale["This page has been locked by the administrator so your changes can not be saved."] =
   "Cette page a t verrouille par l'administrateur et vos changements n'ont pas pu tre enregistre.";
$locale["This plugin is currently under development and does not work!"] =
   "Ce plugin est en cours de dveloppement et ne marche pas !";
$locale["Time Zone"] =
   "Fuseau Horaire";
$locale["Title"] =
   "Titre";
$locale["Title Search"] =
   "Recherche par titre";
$locale["Title search results for '%s'"] =
   "Rsultat de recherche sur les titres de pages pour '%s'";
$locale["Title:"] =
   "Titre :";
$locale["TitleSearch"] =
   "RechercheParTitre";
$locale["To add check 'Add' near the dropdown list."] =
   "Pour ajouter cocher 'Add' prs de la liste droulante.";
$locale["To ignore delete the line."] =
   "Pour ignorer effacez la ligne.";
$locale["Today"] =
   "Aujourd'hui";
$locale["Too many external links."] =
   "Trop de liens exterieurs.";
$locale["Top & bottom toolbars"] =
   "Barres d'outils en haut et en bas";
$locale["Total %d plugins: "] =
   "%d plugins au total : ";
$locale["Total of %d languages: "] =
   "%d langages au total : ";
$locale["Total of %d themes: "] =
   "%d thmes au total: ";
$locale["Transclude"] =
   "Insrer";
$locale["TranscludePlugin"] =
   "PluginInsrer";
$locale["Transcluded from %s"] =
   "Insr de %s";
$locale["Transcluded page"] =
   "Page insres";
$locale["Translate"] =
   "Traduire";
$locale["Translate %s to %s in %s"] =
   "Traduire de %s  %s en %s";
$locale["Translate '%s' to '%s' in *%s*"] =
   "Traduire de '%s'  '%s' en *%s*";
$locale["TranslateText"] =
   "TraduireUnTexte";
$locale["Translation Error!"] =
   "Erreur de traduction !";
$locale["Type"] =
   "Type";
$locale["Type it again"] =
   "Verrification";
$locale["UNOBTAINABLE"] =
   "INACCESSIBLE";
$locale["USER"] =
   "UTILISATEUR";
$locale["Unable to bind LDAP server %s using %s %s"] =
   "Impossible de se connecter au serveur LDAP %s, avec %s %s";
$locale["Unable to connect to IMAP server "] =
   "Impossible de se connecter au serveur IMAP ";
$locale["Unable to connect to LDAP server %s"] =
   "Impossible de se connecter au serveur LDAP %s";
$locale["Unable to load: %s"] =
   "Impossible de charger : %s";
$locale["Unable to open directory '%s' for reading"] =
   "Impossible d'ouvrir le rpertoire '%s' en lecture";
$locale["Unable to read src='%s'"] =
   "Impossible de lire src=%s";
$locale["Undefined method %s for special group %s"] =
   "Mthode non dfinie %s pour le groupe %s";
$locale["Undo"] =
   "Annuler l'action";
$locale["Undo Search & Replace"] =
   "Undo Recherche & Remplace";
$locale["Undo disabled"] =
   "Annuler dernire action dsactiv.";
$locale["Unexpected EOF in zip file"] =
   "Fin de fichier (EOF) inattendue dans le fichier Zip";
$locale["UnfoldSubpages"] =
   "ListeDesSousPages";
$locale["UnfoldSubpagesPlugin"] =
   "PluginListeSousPages";
$locale["Unknown special group '%s'"] =
   "Le groupe speciale %s non dfinie";
$locale["Unlock"] =
   "Dverrouiller";
$locale["Unlock Page"] =
   "Dverrouiller la page";
$locale["Unlocking pages"] =
   "Dverrouiller les pages";
$locale["Unsupported ACL access type %s ignored."] =
   "Le type d'accs ACL %s n'est pas support. -- Ignor.";
$locale["Unsupported argument: %s=%s"] =
   "Argument %s=%s n'est pas support !";
$locale["Up"] =
   "Haut";
$locale["UpLoad"] =
   "DposerUnFichier";
$locale["UpLoadPlugin"] =
   "PluginDposer";
$locale["Update Preferences"] =
   "Mettre  jour les prfrences";
$locale["Upgrade"] =
   "Mettre  jour";
$locale["Upgrade disabled: user != isAdmin"] =
   "Mise  jour dsactive, vous n'tes pas administrateur";
$locale["Upgrading this PhpWiki"] =
   "Mise  jour du PhpWiki";
$locale["Upload"] =
   "Dposer";
$locale["Upload File"] =
   "Dposer le fichier";
$locale["Upload files to the local InterWiki Upload:<filename>"] =
   "Transfrer les fichiers vers Upload:<filename>";
$locale["Uploading %s"] =
   "Dpt de %s";
$locale["Uploading failed."] =
   "chec du dpt.";
$locale["Uploading zip dumps"] =
   "Dposer la sauvegarde compresse";
$locale["Use old markup"] =
   "Anciennes rgles";
$locale["User page"] =
   "Page Utilisateur";
$locale["User preferences for user '%s':"] =
   "Prfrences utilisateurs pour l'utilisateur %s :";
$locale["User statistics"] =
   "Statistiques d'utilisateur";
$locale["User: %s"] =
   "Utilisateur : %s";
$locale["UserId"] =
   "IdentifiantUtilisateur";
$locale["UserId:"] =
   "Nom d'utilisateur :";
$locale["UserPreferences"] =
   "PrfrencesUtilisateurs";
$locale["UserRatings"] =
   "Statistiques d'utilisateur";
$locale["Users will not be able to sign in."] =
   "Les utilisateurs ne pourront pas s'inscrire.";
$locale["Using directory '%s'"] =
   "Utilisation du rpertoire '%s'";
$locale["Verification Status"] =
   "Vrification du statut";
$locale["Verify the current action"] =
   "Vrifier l'action actuelle";
$locale["Version"] =
   "Version";
$locale["Version %d"] =
   "Version %d";
$locale["Version %s"] =
   "Version %s";
$locale["Version %s, saved %s"] =
   "Version %s, enregistre %s";
$locale["Version %s, saved on %s"] =
   "Version %s, enregistre sur %s";
$locale["Versions are identical"] =
   "Les versions sont identiques";
$locale["View Source"] =
   "Afficher la Source";
$locale["View Source: %s"] =
   "Afficher la Source : %s";
$locale["View a single page dump online."] =
   "Voir une sauvegarde de page en ligne.";
$locale["View the current version"] =
   "Visualiser la version actuelle";
$locale["View this page and all subpages"] =
   "Voir cette page et ses sous-pages";
$locale["Viewing redirecting page."] =
   "Consultation des pages de redirection.";
$locale["Viewing the source of pages"] =
   "Visualisation de la source des pages";
$locale["Visited pages on this wiki, ordered by popularity:"] =
   "Pages visites sur ce wiki, classes par ordre de popularit :";
$locale["Visualizes the Wiki structure in a graph using the 'dot' commandline tool from graphviz."] =
   "Reprsenter la structure du wiki par un graphe utilisant l'outil dot de graphviz.";
$locale["W"] =
   "L";
$locale["WabiSabi"] =
   "WabiSabi";
$locale["Wanted From"] =
   "Recherches par";
$locale["Wanted Pages for %s (%d total):"] =
   "Pages recherches pour %s  dans ce wiki (%d au total) :";
$locale["Wanted Pages for %s:"] =
   "Pages recherches pour %s :";
$locale["Wanted Pages in this wiki (%d total):"] =
   "Pages recherches dans ce wiki (%d au total) :";
$locale["Wanted Pages in this wiki:"] =
   "Pages recherches dans ce wiki :";
$locale["WantedPages"] =
   "PagesRecherches";
$locale["Warning!"] =
   "Attention !";
$locale["Warning:"] =
   "Attention:";
$locale["Warning: The search string cannot be empty!"] =
   "ATTENTION: vous devez entrez au moins une lettre pour la recherche!";
$locale["Warning: You are editing an old revision."] =
   "Avertissement : Vous ditez une version archive.";
$locale["We have a total of %d registered users."] =
   "Nous avons %d utilisateurs enregistrs.";
$locale["Welcome to %s!\nYour email account is verified and\nwill be used to send page change notifications.\nSee %s"] =
   "Bienvenue sur %s!\nVotre compte email a t vrifi et\nsera utilis pour les notifications de changements de pages.\nVoir %s";
$locale["What links here"] =
   "Quels liens ici";
$locale["White space converted to single space"] =
   "Espace blanc converti en espace simple";
$locale["Who Is Online"] =
   "Qui est en ligne";
$locale["Who is online"] =
   "Qui est en ligne";
$locale["WhoIsOnline"] =
   "QuiEstEnLigne";
$locale["Width"] =
   "Largeur";
$locale["Wiki Name"] =
   "Nom Wiki";
$locale["WikiAdminChmod"] =
   "AdministrationDePhpWiki/Droits";
$locale["WikiAdminChown"] =
   "WikiAdminChown";
$locale["WikiAdminMarkup from %s to %s"] =
   "WikiAdminMarkup %s par %s";
$locale["WikiAdminRemove"] =
   "WikiAdminSupprimer";
$locale["WikiAdminRename"] =
   "WikiAdminRenommer";
$locale["WikiAdminSearchReplace"] =
   "WikiAdminRemplacementRecherche";
$locale["WikiAdminSearchReplace %s by %s"] =
   "WikiAdminRemplacementRecherche %s par %s";
$locale["WikiAdminSelect"] =
   "WikiAdminSelect";
$locale["WikiAdminSetAcl"] =
   "WikiAdminSetAcl";
$locale["WikiAdminUtils"] =
   "WikiAdminUtils";
$locale["WikiAdminUtils says:"] =
   "WikiAdminUtils dit :";
$locale["WikiBlog"] =
   "WikiBlog";
$locale["WikiBlogPlugin"] =
   "PluginWikiBlog";
$locale["WikiDB::renamePage() not yet implemented for this backend"] =
   "WikiBD::renamePage() pas encore implmente pour le Principal";
$locale["WikiForm"] =
   "WikiForm";
$locale["WikiForm: %s: unknown action"] =
   "FormulaireWiki : %s : action inconnue";
$locale["WikiForum"] =
   "WikiForum";
$locale["WikiPlugin"] =
   "PluginWiki";
$locale["WikiPoll"] =
   "WikiPoll";
$locale["WikiWikiWeb"] =
   "WikiWikiWeb";
$locale["Wikiname regexp"] =
   "regexp du WikiNom";
$locale["With the current offset, this would be reported as %s."] =
   "Avec l'offset actuel, ceci serait affich comme %s.";
$locale["World"] =
   "Monde";
$locale["Wrong password. Try again."] =
   "Mot de passe invalide, essayez encore.";
$locale["XML-RPC access"] =
   "Accs XML-RPC";
$locale["Yes"] =
   "Oui";
$locale["You are about to remove '%s'!"] =
   "Vous tes sur le point de supprimer ' %s ' de faon permanente !";
$locale["You are signed but not authenticated as %s. "] =
   "Vous tes enregistr mais pas connect en tant que %s. ";
$locale["You are signed in as %s"] =
   "Vous tes connect comme %s";
$locale["You are viewing an old revision of this page."] =
   "Vous lisez une ancienne rvision de cette page.";
$locale["You can only use it via the _WikiTranslation plugin."] =
   "Vous pouvez uniquement l'utiliser via le plugin _WikiTranslation.";
$locale["You can personalize various settings in %s."] =
   "Vous pouvez personnaliser quelques prfrences dans %s.";
$locale["You forgot to set ENCRYPTED_PASSWD to true. Please update your config/config.ini"] =
   "Vous avez oubli de mettre ENCRYPTED_PASSWD  true. Veuillez diter votre config/config.ini";
$locale["You have not made any changes so no new version has been saved."] =
   "Vous n'avez effectu aucun changement, aucune nouvelle version n'a donc t enregistre.";
$locale["You have to define PHPWEATHER_BASE_DIR before use. (config/config.ini)"] =
   "Vous devez dfinir PHPWEATHER_BASE_DIR avant de l'utiliser (config/config.ini)";
$locale["You may sign in using any [WikiWord|AddingPages] as a user id. (Any characters in %s etc. may be used too). The user id will be used as a link in RecentChanges to your home page."] =
   "Vous pouvez vous inscrire en utilisant n'importe quel WikiMot comme identifiant utilisateur ( peuvent tre utiliss). L'identifiant sera utilis comme lien vers votre PagePersonnelle dans DerniresModifs.";
$locale["You must be an administrator to %s."] =
   "Vous devez tre un administrateur pour %s.";
$locale["You must be an administrator to use this plugin."] =
   "Vous devez tre un administrateur pour utiliser ce plugin.";
$locale["You must be logged in to view ratings."] =
   "Vous devez vous connecter pour voir les scores.";
$locale["You must log in to %s."] =
   "Vous devez vous connecter pour %s.";
$locale["You must sign in to %s."] =
   "Vous devez vous inscrire pour %s.";
$locale["You must specify a directory to dump to"] =
   "Vous devez spcifier un rpertoire pour l'archivage de la sauvegarde";
$locale["You stored an empty password in your '%s' page."] =
   "Vous n'avez pas saisi de mot de passe pour la page %s.";
$locale["Your E-Mail:"] =
   "Votre E-Mail :";
$locale["Your UserPreferences have been successfully deleted."] =
   "Vos PrfrencesUtilisateurs ont t effaces avec succs.";
$locale["Your WikiDB DB backend '%s' cannot be used for DbSession."] =
   "Votre choix '%s' de WikiDB DB ne peut pas tre utilis pour DbSession.";
$locale["Your access permissions are only for a BogoUser."] =
   "Vos permissions d'acces sont celles d'un utilisateur Bogo.";
$locale["Your are probably trying to edit/create an invalid version of this page."] =
   "Vous lisez une ancienne rvision de cette page.";
$locale["Your browser should have redirected you to %s."] =
   "Votre navigateur aurait du vous redirig vers %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Votre souci particulier du dtail est trs apprci.";
$locale["Your changes can not be saved as they are, since doing so would overwrite the other author's changes. So, your changes and those of the other author have been combined. The result is shown below."] =
   "Vos modifications ne peuvent tre enegistres, puisqu'elles craseraient celles de l'autre utilisateur. Ainsi donc, vos modifications et celles de l'autre auteur ont t combines. Le rsultat est affich ci-dessous.";
$locale["Your home page has not been created yet so your preferences cannot not be saved."] =
   "Cette page a t verrouille par l'administrateur et vos changements n'ont pas pu tre enregistre.";
$locale["Your home page is locked so your preferences cannot not be saved."] =
   "Cette page a t verrouille par l'administrateur et vos changements n'ont pas pu tre enregistre.";
$locale["Your rating was %.1f"] =
   "Votre note est %.1f";
$locale["Your signature"] =
   "Votre signature";
$locale["Your translated text doesn't yet appear in this %s, but the Administrator will pick it up and add to the installation."] =
   "Le texte traduit n'apparait pas encore dans ce %s, mais l'administrateur l'ajoutera  l'installation.";
$locale["Your translated text is either empty or equal to the untranslated text. Please try again."] =
   "Soit votre texte est vide soit il est le mme que le texte  traduire, veuillez ressayer.";
$locale["Your translation is stored in %s"] =
   "Votre traduction est enregistre dans %s";
$locale["Your version"] =
   "Votre version";
$locale["[%d] See [%s]"] =
   "[%d] Voir [%s]";
$locale["[purged]"] =
   "[purg]";
$locale["_WikiTranslation"] =
   "_WikiTranslation";
$locale["access this wiki via SOAP"] =
   "accder  ce wiki via SOAP";
$locale["access this wiki via XML-RPC"] =
   "accder  ce wiki via XML-RPC";
$locale["add "] =
   "ajouter";
$locale["always skip the HomePage."] =
   "toujours ignorer la page d'accueil.";
$locale["argument '%s' not declared by plugin"] =
   "argument '%s' non dclar par le plugin";
$locale["authenticated"] =
   "authentifi";
$locale["blog"] =
   "blog";
$locale["by"] =
   "par";
$locale["by %s"] =
   "par %s";
$locale["cached pagedata:"] =
   "page bufferise :";
$locale["cached versiondata:"] =
   "version bufferise :";
$locale["case-exact"] =
   "respect de la casse";
$locale["check for extra page.cached_html column"] =
   "recherche une extra colonne page.cached_html";
$locale["check for mysql 4.1.x/5.0.0 binary search on windows problem"] =
   "vrifier la recherche binaire de bug pour mysql 4.1.x (Windows)";
$locale["check for mysql page.id auto_increment flag"] =
   "vrifie le marqueur auto_increment pour page.id";
$locale["check for mysql session.sess_id sanity"] =
   "recherche une nouvelle colonne session.sess_ip";
$locale["check for necessary ActionPage updates"] =
   "vrifie les mises  jour d'ActionPage ncessaire";
$locale["check for necessary config updates"] =
   "vrifie les mises  jour de configuration ncessaire";
$locale["check for necessary database updates"] =
   "rechercher des mises  jour ncessaire dans la base de donnes";
$locale["check for necessary pgsrc updates"] =
   "recherche les mises  jour ncessaire des pages sources";
$locale["check for necessary plugin argument updates"] =
   "recherche les mises  jour ncessaire des plugin argument";
$locale["check for new session.sess_ip column"] =
   "recherche une nouvelle colonne session.sess_ip";
$locale["check for table %s"] =
   "vrifie la table %s";
$locale["chmod page '%s' to '%s'."] =
   "Changement de mode %s  %s.";
$locale["comments"] =
   "commentaires";
$locale["compare revisions"] =
   "comparer les rvisions";
$locale["content is identical to current version %d - no new revision created"] =
   "contenu est identique  la version en cours %d - pas de rvision";
$locale["couldn't move %s to %s"] =
   "impossible de dplacer %s en %s";
$locale["couldn't open file '%s' for writing"] =
   "Impossible d'ouvrir le fichier '%s' en criture";
$locale["create this page"] =
   "crer cette page";
$locale["current version"] =
   "version actuelle";
$locale["days"] =
   "jours";
$locale["default page permission"] =
   "Permission de page par dfaut";
$locale["diff"] =
   "diff";
$locale["diff this page"] =
   "diff de cette page";
$locale["download a zip dump from this wiki"] =
   "tlcharger une sauvegarde compresse de ce wiki";
$locale["dump html pages"] =
   "rcupration des pages HTML";
$locale["dump serial pages"] =
   "rcupration des pages srialises";
$locale["edit area"] =
   "Zone d'dition";
$locale["edit this page"] =
   "diter cette page";
$locale["edits"] =
   "ditions";
$locale["empty source"] =
   "source vide";
$locale["from"] =
   "de";
$locale["from %s"] =
   "du %s";
$locale["getfacl"] =
   "getfacl";
$locale["has edit conflicts - overwriting anyway"] =
   "conflits d'dition - craser quand mme ";
$locale["has edit conflicts - skipped"] =
   "a des conflits d'dition - ignor";
$locale["home page"] =
   "Page d'accueil";
$locale["invalid %s ignored"] =
   "%s non valable ignor";
$locale["invalid argument %s"] =
   "Argument non valable %s";
$locale["invidual page permission"] =
   "Permission de page individuelle";
$locale["latest comment by "] =
   "dernier commentaire by ";
$locale["load files into this wiki"] =
   "chargement des fichiers sur ce wiki";
$locale["lock this page"] =
   "verrouiller cette page";
$locale["locked"] =
   "verrouille";
$locale["major edits"] =
   "ditions majeures";
$locale["max: %d"] =
   "maximum : %d";
$locale["mean: %2.3f"] =
   "moyenne : %2.3f";
$locale["median: %d"] =
   "mdiane : %d";
$locale["minor"] =
   "mineure";
$locale["minor edit"] =
   "dition mineure";
$locale["minor edits"] =
   "ditions mineures";
$locale["minutes"] =
   "minutes";
$locale["missing required version argument"] =
   "argument de version requis manquant";
$locale["mode"] =
   "mode";
$locale["n/a"] =
   "n/c";
$locale["name"] =
   "nom";
$locale["newer than the existing page."] =
   "plus rcent que la page existante.";
$locale["no cache used"] =
   "pas de cache utilis";
$locale["no page content"] =
   "pas de sommaire de page";
$locale["no page specified"] =
   "aucune page indique";
$locale["not affected"] =
   "non affecte";
$locale["not authenticated"] =
   "non authentifi";
$locale["not yet"] =
   "pas encore";
$locale["older than the existing page."] =
   "plus vieux que la page existante.";
$locale["only %d pages displayed"] =
   "Seulement %d pages affiches";
$locale["optional label | PageName"] =
   "en option | PageName";
$locale["optional label | http://www.example.com"] =
   "en option | http://www.example.com";
$locale["page permission inherited from %s"] =
   "permissions hrites de %s";
$locale["period"] =
   "period";
$locale["plain file %s"] =
   "fichier simple %s";
$locale["predecessor to the previous major change"] =
   "prdcesseur de la modification majeure prcdente";
$locale["previous revision"] =
   "rvision prcdente";
$locale["recursive inclusion of page %s"] =
   "insertion rcursive de la page %s";
$locale["recursive inclusion of page %s ignored"] =
   "insertion rcursive de la page %s ignor";
$locale["recursive inclusion of url %s"] =
   "insertion rcursive de l'URL %s";
$locale["regex"] =
   "expression rgulire";
$locale["remove this page"] =
   "supprimer cette page";
$locale["renamed from %s"] =
   "renomme  partir de %s";
$locale["revert to a previous version of this page"] =
   "revenir  une prcdente version de cette page.";
$locale["revert to version %d"] =
   "revenir  la version %d";
$locale["revision by previous author"] =
   "rvision par auteur prcdent";
$locale["same version page"] =
   "mme version de page";
$locale["saved as "] =
   "enregistre sous ";
$locale["saved as %s"] =
   "enregistre sous %s";
$locale["sortby=mtime not supported with MostPopular"] =
   "sortby=mtime non support avec MostPopular";
$locale["stddev: %2.3f"] =
   "cart-type : %2.3f";
$locale["the file '%s'"] =
   "le fichier %s";
$locale["the session.save_path directory '%s'"] =
   "le rpertoire 'session.save_path' '%s'";
$locale["to"] =
   "";
$locale["today"] =
   "aujourd'hui";
$locale["too long"] =
   "trop long";
$locale["total hits: %d"] =
   "%d visites totales";
$locale["trailing cruft in plugin args: '%s'"] =
   "cochonneries terminant les arguments du plugin : '%s'";
$locale["unknown argument '%s' to SystemInfo"] =
   "argument inconnu pour SystemInfo (%s)";
$locale["unknown color %s ignored"] =
   "%s color non valable ignor";
$locale["unlock this page"] =
   "dverrouiller la Page";
$locale["upload a zip dump"] =
   "dposer un fichier zip";
$locale["uploaded %s"] =
   "dpt de %s";
$locale["use this plugin"] =
   "utiliser ce plugin";
$locale["users"] =
   "utilisateurs";
$locale["verify the current action"] =
   "vrifier l'action actuelle";
$locale["version %d"] =
   "version %d";
$locale["version %s"] =
   "version %s";
$locale["version <em>%s</em>"] =
   "version <em>%s</em>";
$locale["version <em>%s</em> not affected"] =
   "version <em>%s</em> non affecte";
$locale["view the source of this page"] =
   "voir la source de cette page";
$locale["view this page"] =
   "voir cette page";
$locale["yesterday"] =
   "hier";
$locale["|<<"] =
   "|<<";

?>
